VChip

Struct VChip 

pub struct VChip<'a, 'b, 'c>
where 'b: 'a, 'c: 'b,
{ /* private fields */ }
Virtual chip of the DCMI

Implementations

Source

impl<'a, 'b, 'c> VChip<'a, 'b, 'c>
where 'b: 'a, 'c: 'b,

pub fn new_unchecked(chip: &'a Chip<'b, 'c>, id: u32, vfg_id: u32) -> Self

Create a new virtual chip

Warning

It is your responsibility to ensure that the virtual chip ID is valid

pub fn id(&self) -> u32

Query the ID of this virtual chip

pub fn vfg_id(&self) -> u32

Query the group ID of this virtual chip

pub fn chip(&self) -> &Chip<'_, '_>

Query the chip of this virtual chip

Returns

chip

pub fn create( chip: &'a Chip<'b, 'c>, param: VChipCreateParam, ) -> DCMIResult<(VChipOutput, Self)>

Create a virtual chip

Warning

if param is VChipCreateParam::SpecificId, make sure that the id is not 65535

Parameters
  • chip: the chip you want to create a virtual chip on
  • param: virtual chip creation parameters
Returns
  • out: output virtual chip info
pub fn destroy_all(chip: &'a Chip<'b, 'c>) -> DCMIResult<()>

Destroy all virtual chips

Parameters
  • chip: the chip you want to destroy all virtual chips on
Source

impl VChip<'_, '_, '_>

pub fn set_compute_power_splitting_mode( _dcmi: &DCMI, mode: VChipPowerSplittingMode, ) -> DCMIResult<()>

Set the computing power splitting mode

Parameters
  • mode: computing power splitting mode
Warning

make sure that no vchip is created before calling this function

pub fn get_compute_power_splitting_mode( _dcmi: &DCMI, ) -> DCMIResult<VChipPowerSplittingMode>

Query the computing power splitting mode

Returns

computing power splitting mode

pub fn set_recovery_mode(_dcmi: &DCMI, mode: bool) -> DCMIResult<()>

Set the vchip configuration recover mode

Parameters
  • mode: vchip configuration recover mode (0: disable, 1: enable)
pub fn get_recovery_mode(_dcmi: &DCMI) -> DCMIResult<bool>

Query the vchip configuration recover mode

Returns

vchip configuration recover mode (0: disable, 1: enable)

Source

impl VChip<'_, '_, '_>

pub fn destroy(self) -> DCMIResult<()>

Destroy VChip