pub enum VChipCreateParam {
TemplateName(String),
SpecificId {
template_name: String,
id: u32,
group_id: u32,
},
}Expand description
VChip create parameter
Variants
TemplateName(String)
Create a VChip with a specific template name, vchip id and group id will automatically assigned
SpecificId
Create a VChip with a specific template name, vchip id and group id